@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -23,6 +23,7 @@ KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     , mTurnOffAllMessages(new QPushButton(i18n("Turn Off All Messages"), this))
 {
     auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mTreeListWidget->setObjectName(QStringLiteral("listwidget"));
 
@@ -51,9 +52,7 @@ KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     mTreeListWidgetSearchLine->installEventFilter(this);
 }
 
-KDEApplicationDebugSettingPage::~KDEApplicationDebugSettingPage()
-{
-}
+KDEApplicationDebugSettingPage::~KDEApplicationDebugSettingPage() = default;
 
 void KDEApplicationDebugSettingPage::forceFocus()
 {
